const express = require("express");
const app = express();
const bodyParser = require("body-parser");
const mysql = require("mysql2");
const cors = require("cors");
const multer = require('multer');
const path = require('path');

const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    cb(null, 'uploads/');
  },
  filename: function (req, file, cb) {
    cb(null, Date.now() + '-' + file.originalname);
  }
});

const upload = multer({ storage: storage });

const db = mysql.createPool({
  host: "localhost",
  user: "root",
  password: "",
  database: "mumber2"
});

app.use(cors());
app.use(express.json());
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: true }));

// Serve uploaded images from the uploads directory
app.use('/uploads', express.static(path.join(__dirname, 'uploads')));

app.get('/api/images', (req, res) => {
  const query = 'SELECT images FROM blogs';
  db.query(query, (err, result) => {
    if (err) {
      console.log(err);
      return res.status(500).json({
        success: false,
        message: 'Internal Server Error'
      });
    }

    const images = result.map((row) => row.images);
    res.json({
      success: true,
      data: images.map(image => `/uploads/${image}`) // add '/uploads/' prefix to image URLs
    });
  });
});

app.post('/api/upload', upload.single('image'), (req, res) => {
  const file = req.file;
  if (!file) {
    return res.status(400).json({ error: 'No file uploaded' });
  }

  const imageUrl = file.filename;
  const query = 'INSERT INTO image (image) VALUES (?)';
  db.query(query, [imageUrl], (err, result) => {
    if (err) throw err;
    res.status(200).json({ message: 'File uploaded successfully and saved to database', imageUrl });
  });
});

app.listen(5000, () => {
  console.log("Server is running on port 5000");
});
